@@ -25,6 +25,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 ******************************************************************/
 
 #include "ktipdialog.h"
+#include "kconfigwidgets_debug.h"
 
 #include <QApplication>
 #include <QFile>
@@ -35,7 +36,6 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <QDesktopWidget>
 #include <QPushButton>
 #include <QTextBrowser>
-#include <QDebug>
 
 #include <kconfig.h>
 #include <kconfiggroup.h>
@@ -71,13 +71,13 @@ void KTipDatabase::Private::addTips(const QString &tipFile)
     const QString fileName = QStandardPaths::locate(QStandardPaths::GenericDataLocation, tipFile);
 
     if (fileName.isEmpty()) {
-        qDebug() << "KTipDatabase::addTips: can't find '" << tipFile << "' in standard dirs";
+        qCDebug(KCONFIG_WIDGETS_LOG) << "KTipDatabase::addTips: can't find '" << tipFile << "' in standard dirs";
         return;
     }
 
     QFile file(fileName);
     if (!file.open(QIODevice::ReadOnly)) {
-        qDebug() << "KTipDatabase::addTips: can't open '" << fileName << "' for reading";
+        qCDebug(KCONFIG_WIDGETS_LOG) << "KTipDatabase::addTips: can't open '" << fileName << "' for reading";
         return;
     }
 
@@ -104,7 +104,7 @@ void KTipDatabase::Private::addTips(const QString &tipFile)
         }
 
         if (tip.isEmpty()) {
-            qDebug() << "Empty tip found! Skipping! " << pos;
+            qCDebug(KCONFIG_WIDGETS_LOG) << "Empty tip found! Skipping! " << pos;
             continue;
         }
 
@@ -120,7 +120,7 @@ KTipDatabase::KTipDatabase(const QString &_tipFile)
     QString tipFile = _tipFile;
 
     if (tipFile.isEmpty()) {
-        tipFile = QCoreApplication::applicationName() + "/tips";
+        tipFile = QCoreApplication::applicationName() + QStringLiteral("/tips");
     }
 
     d->loadTips(tipFile);
@@ -134,7 +134,7 @@ KTipDatabase::KTipDatabase(const QStringList &tipsFiles)
     : d(new Private)
 {
     if (tipsFiles.isEmpty() || ((tipsFiles.count() == 1) && tipsFiles.first().isEmpty())) {
-        d->addTips(QCoreApplication::applicationName() + "/tips");
+        d->addTips(QCoreApplication::applicationName() + QStringLiteral("/tips"));
     } else {
         for (QStringList::ConstIterator it = tipsFiles.begin(); it != tipsFiles.end(); ++it) {
             d->addTips(*it);
@@ -324,10 +324,10 @@ KTipDialog::KTipDialog(KTipDatabase *database, QWidget *parent)
     KConfigGroup config(KSharedConfig::openConfig(), "TipOfDay");
     d->tipOnStart->setChecked(config.readEntry("RunOnStart", true));
 
-    connect(next, SIGNAL(clicked()), this, SLOT(_k_nextTip()));
-    connect(prev, SIGNAL(clicked()), this, SLOT(_k_prevTip()));
-    connect(ok, SIGNAL(clicked()), this, SLOT(accept()));
-    connect(d->tipOnStart, SIGNAL(toggled(bool)), this, SLOT(_k_showOnStart(bool)));
+    connect(next, &QPushButton::clicked, this, [this]() { d->_k_nextTip(); });
+    connect(prev, &QPushButton::clicked, this, [this]() { d->_k_prevTip(); });
+    connect(ok, &QAbstractButton::clicked, this, &QDialog::accept);
+    connect(d->tipOnStart, &QCheckBox::toggled, this, [this](bool state) { d->_k_showOnStart(state); });
 
     ok->setFocus();
 
